### Global

- **Ctrl + t** — switch to typing screen  
- **Ctrl + s** — switch to settings  
- **Ctrl + p** — switch to profile  

**Navigation:**

- **j / Tab / ↓** — next item  
- **k / Shift + Tab / ↑** — previous item  

---

### Settings

- **Ctrl + z** — undo changes  
- **Ctrl + d** — reset to default values  

- **PageDown / Ctrl + f** — next settings group  
- **PageUp / Ctrl + b** — previous settings group  

---

### Lists and dropdowns

- **Enter / Space / l** — open / close list  

> Navigation uses global keys ↑ / ↓ or j / k.

---

### Sliders and numeric values

- **h / ← / -** — decrease value  
- **l / → / + / =** — increase value  

---

💡 Main hotkeys are also displayed in the bottom panel.  
The footer can be hidden with **Ctrl + o**.
